require 'commander/blank'
require 'commander/command'

module PolyglotFlutter
  module Command
    class Projects
      include Helper::Terminal
      include Helper::General

      attr_accessor :options

      def self.init(options = Commander::Command::Options.new)
        new(options).call
      end

      def initialize(options = Commander::Command::Options.new)
        @options = options
      end

      def call
        list_projects
      end

      def filtered_projects
        projects
          .select { |key, _id| key[/^(.*?(#{option_query})[^$]*)$/i] }
          .sort_by { |p| p[0].downcase }
          .to_h
      end

      def projects
        prompt.say('Getting projects...')
        PolyglotFlutter::Resource::Project.token(token).depaginate.each_with_object({}) do |r, hash|
          hash[r.name] = r.id
        end
      end

      def option_query
        @option_query ||= @options.__hash__.fetch(:query, '')
      end

      private

      def list_projects
        projects = filtered_projects
        selection = projects
                    .each_with_object({}) do |project, hash|
          project_name = project[0]
          project_id = project[1]
          display_name = "#{project_name} => #{project_id}"
          hash[display_name] = project_id
        end
        prompt.say("  Name - ID: \n  ----------")
        selected_id = prompt
                      .select('', selection)
      end
    end
  end
end
