module PolyglotFlutter
  module Command
    class Pull
      include Helper::Terminal
      include Helper::General

      def self.init
        new.call
      end

      def call
        prompt.say('Fetching translations...')
        generate_translations(project_configs)
        success('Translations successfully generated!')
      end

      private

      def generate_translations(projects)
        projects.each do |project|
          project_id = project[:id]
          flutter_instance = project[:flutterInstance]
          mandatory_language = project[:mandatoryLanguage]
          arb_path = project[:path]
          l10n_path = project[:l10nFilePath]
          directory_path = project[:sourceFilesPath]
          output_localization_file = project[:outputLocalizationFile]
          set_default_langauge = project[:setDefaultLangauge]

          languages = pull_languages(project_id)
          translation_keys = pull_translation_keys(project_id)
          
          write_translations(translation_keys, languages, arb_path)
          write_l10n_yaml(l10n_path, arb_path, mandatory_language, output_localization_file)

          script = "#{flutter_instance} packages get"
          `#{script}`
          
          write_localization(directory_path, languages, output_localization_file, set_default_langauge, mandatory_language)
          
        end
      end

      # Serializing data

      def write_translations(translation_keys, languages, translations_path)
        return if translations_path.to_s.empty?

        languages.each do |language|
          PolyglotFlutter::Serializer::Translation
            .write(translation_keys, language, translations_path)
        end
      end

      def write_l10n_yaml(l10n_path, arb_path, mandatory_language, output_localization_file)
        return if l10n_path.to_s.empty?

        PolyglotFlutter::IO::L10n
          .write(l10n_path, arb_path, mandatory_language, output_localization_file)
      end

      def write_localization(directory_path, languages, output_localization_file, set_default_langauge, mandatory_language)
        return if directory_path.to_s.empty?

        PolyglotFlutter::Serializer::Localization::Localization
          .new(languages: languages)
          .write(directory_path, output_localization_file, set_default_langauge, mandatory_language)
      end

      # Pulling data

      def pull_languages(project_id)
        PolyglotFlutter::Resource::Language
          .token(token)
          .depaginate(project_id: project_id)
      end

      def pull_translation_keys(project_id)
        PolyglotFlutter::Resource::TranslationKey
          .token(token)
          .depaginate(project_id: project_id)
          .sort_by { |key| key.name.downcase }
      end
    end
  end
end
