require 'commander/blank'
require 'commander/command'

module PolyglotFlutter
  module Command
    class Setup < Projects
      include Helper::Terminal
      include Helper::General

      def self.init(options = Commander::Command::Options.new)
        new(options).call
      end

      def initialize(options = Commander::Command::Options.new)
        @options = options
      end

      def call
        project_id = project_id_prompt
        flutter_instance = flutter_instance_prompt
        l10n_path = './l10n.yaml'
        output_localization_file = 'app_localizations'
        set_default_langauge = false
        translations_path = translations_path_prompt
        
        sources_path = sources_path_prompt
        mandatory_language = mandatory_language_prompt
        project = {
          id: project_id,
          flutterInstance: flutter_instance,
          mandatoryLanguage: mandatory_language,
          path: translations_path,
          l10nFilePath: l10n_path,
          sourceFilesPath: sources_path,
          outputLocalizationFile: output_localization_file,
          setDefaultLangauge: set_default_langauge,
        }
        config = {
          projects: [project],
        }
        PolyglotFlutter::IO::Config.write(config)
        success
      end

      private

      # Project ID

      def project_id_prompt
        prompt.select('Choose a project: ', filtered_projects)
      end

      # Flutter instaince

      def flutter_instance_prompt
        prompt.ask('What Flutter instance are you using (flutter/fvm flutter/...)?', default: 'flutter')
      end

      # Translations path

      def translations_path_prompt
        prompt.ask('Where would you like to store translation files (.arb)?', default: './assets/i18n/')
      end

      # Sources path

      def sources_path_prompt
        prompt.ask('Where would you like to store source files?', default: './lib/util/localization/')
      end

      # Mandatory language

      def mandatory_language_prompt
        prompt.ask('What is the mandatory (main) language on polyglot?', default: 'en')
      end
    end
  end
end
